pub enum WasmMemoryError {
BytesNotPageAligned,
PageCountOverflow,
MaximumLessThanMinimum,
}Expand description
Error returned when memory limits are invalid.
Variants
BytesNotPageAligned
The byte count is not a whole number of Wasm pages.
PageCountOverflow
The page count does not fit in ‘u32’.
MaximumLessThanMinimum
The maximum page count is lower than the minimum page count.