MemoryLimits

Struct MemoryLimits 

pub struct MemoryLimits { /* private fields */ }
Linear memory limit metadata.

Implementations

Source

impl MemoryLimits

pub fn new( minimum: WasmPageCount, maximum: Option<WasmPageCount>, ) -> Result<Self, WasmMemoryError>

Creates memory limits after checking that ‘maximum >= minimum’ when present.

pub const fn with_shared(self, shared: bool) -> Self

Marks the memory as shared or unshared.

pub const fn with_shared_memory(self, shared: SharedMemory) -> Self

Marks the memory with an explicit shared-memory marker.

pub const fn minimum(&self) -> WasmPageCount

Returns the minimum page count.

pub const fn minimum_pages(&self) -> u32

Returns the minimum page count as a raw integer.

pub const fn maximum(&self) -> Option<WasmPageCount>

Returns the maximum page count when bounded.

pub const fn maximum_pages(&self) -> Option<u32>

Returns the maximum page count as a raw integer when bounded.

pub const fn shared_memory(&self) -> SharedMemory

Returns the shared-memory marker.

pub const fn is_shared(&self) -> bool

Returns ‘true’ when the memory is marked as shared.