pub struct MemoryLimits { /* private fields */ }Expand description
Linear memory limit metadata.
Implementations
Sourceimpl MemoryLimits
impl MemoryLimits
Sourcepub fn new(
minimum: WasmPageCount,
maximum: Option<WasmPageCount>,
) -> Result<Self, WasmMemoryError>
pub fn new( minimum: WasmPageCount, maximum: Option<WasmPageCount>, ) -> Result<Self, WasmMemoryError>
Creates memory limits after checking that ‘maximum >= minimum’ when present.
Marks the memory as shared or unshared.
Marks the memory with an explicit shared-memory marker.
Sourcepub const fn minimum(&self) -> WasmPageCount
pub const fn minimum(&self) -> WasmPageCount
Returns the minimum page count.
Sourcepub const fn minimum_pages(&self) -> u32
pub const fn minimum_pages(&self) -> u32
Returns the minimum page count as a raw integer.
Sourcepub const fn maximum(&self) -> Option<WasmPageCount>
pub const fn maximum(&self) -> Option<WasmPageCount>
Returns the maximum page count when bounded.
Sourcepub const fn maximum_pages(&self) -> Option<u32>
pub const fn maximum_pages(&self) -> Option<u32>
Returns the maximum page count as a raw integer when bounded.
Returns the shared-memory marker.
Returns ‘true’ when the memory is marked as shared.